# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject2
# FileName:      read_excel.py
# Author:        YH
# Datetime:      2024/7/13 9:43
# Description:
# ---------------------------------------------------------------------------
import openpyxl

from MyAPIAutoTest_v1.common.read_ini import ReadIni
from MyAPIAutoTest_v1.common.read_json import ReadJson


class ReadExcel:
    def __init__(self, name):
        ini = ReadIni(name)

        self.case_data_dict = ReadJson(ini.get_file_path("case_data"))
        self.case_expect_data_dict = ReadJson(ini.get_file_path("case_expect_data"))
        self.sql_data_dict = ReadJson(ini.get_file_path("sql_data"))

        excel_path = ini.get_file_path("case")
        table = ini.get_table_name("ws")

        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table]
        except Exception as e:
            print("加载工作簿或工作表错误！")
            raise e

    def __get_cell_value(self, lie, row):
        try:
            cell_value = self.ws[lie+str(row)].value
        except Exception as e:
            print("行号或列号格式不正确！")
            raise e
        if cell_value is None:
            return None
        elif cell_value.strip():
            return cell_value.strip()

    def r_module(self, row):
        return self.__get_cell_value("B", row)

    def r_API(self, row):
        return self.__get_cell_value("C", row)

    def r_title(self, row):
        return self.__get_cell_value("D", row)

    def r_lever(self, row):
        return self.__get_cell_value("E", row)

    def r_method(self, row):
        return self.__get_cell_value("F", row)

    def r_path(self, row):
        return self.__get_cell_value("G", row)

    def r_req_type(self, row):
        if self.__get_cell_value("H", row):
            return self.__get_cell_value("H", row).lower()

    def r_case_data(self, row):
        key = self.__get_cell_value("I", row)
        if self.__get_cell_value("I", row):
            return self.case_data_dict[self.r_module(row)][self.r_API(row)][key]

    def r_expect_data(self, row):
        key = self.__get_cell_value("J", row)
        if key:
            return self.case_expect_data_dict[self.r_module(row)][self.r_API(row)][key]

    def r_sql_type(self, row):
        sql_type = self.__get_cell_value("K", row)
        if sql_type:
            return sql_type.lower()

    def r_sql_data(self, row):
        key = self.__get_cell_value("L", row)
        if key:
            return self.sql_data_dict[self.r_module(row)][self.r_API(row)][key]

    def r_updata_key(self, row):
        return self.__get_cell_value("M", row)

    def get_case_data(self):
        case_data_list = []
        for row in range(2, self.ws.max_row+1):
            module = self.r_module(row)
            api = self.r_API(row)
            title = self.r_title(row)
            lever = self.r_lever(row)
            method = self.r_method(row)
            path = self.r_path(row)
            req_type = self.r_req_type(row)
            case_data = self.r_case_data(row)
            expect_data = self.r_expect_data(row)
            sql_type = self.r_sql_type(row)
            sql_data = self.r_sql_data(row)
            update_key = self.r_updata_key(row)
            if method is not None and path is not None:
                # module, api, title, lever,
                case_data_list.append([module, api, title, lever,method, path, req_type, case_data, expect_data, sql_type, sql_data, update_key])
        else:
            return case_data_list


if __name__ == '__main__':
    exlce = ReadExcel("aHuanYo")
    print(exlce.get_case_data())


